@@ -7,13 +7,17 @@ from wsgi_microservice_middleware.cors import CORSMiddleware
 from wsgi_microservice_middleware.request_id import (
     RequestIdFilter, 
     RequestIdMiddleware, 
-    current_request_id
+    current_request_id,
+    RequestIdJsonLogFormatter
 )
 
 __all__ = [
+    
     'CORSMiddleware',
     'RequestIdFilter', 
     'RequestIdMiddleware', 
-    'current_request_id'
+    'current_request_id',
+    'RequestIdJsonLogFormatter'
+
 ]
 
